@@ -5,13 +5,13 @@ const Mainloop = imports.mainloop;
 const Tweener = imports.tweener.tweener;
 
 // gi imports
-const Tb = imports.gi.Tb;
 const Clutter = imports.gi.Clutter;
 const ClutterGst = imports.gi.ClutterGst;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
 const Mx = imports.gi.Mx;
 const Pango = imports.gi.Pango;
+const TheBoard = imports.gi.TheBoard;
 
 // ui imports
 const Thing = imports.ui.thing;
@@ -30,8 +30,6 @@ const _SHOW_BUTTON_BOX_TIME = 0.5;
 const _UPDATE_SIZE_TIME = 0.3;
 const _UPDATE_SIZE_TRANSITION = 'easeOutCubic';
 
-const _SAVE_TEXT_TIMEOUT = 5; // in seconds
-
 function VideoThing(args) {
     this._init(args);
 }
@@ -80,12 +78,11 @@ VideoThing.prototype = {
 
     _createVideoBox : function() {
         this._videoBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.HORIZONTAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         name: "video-thing-video-box" });
-
-        this._videoBox.set_style(this._style);
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               style: this._style,
+                               name: "video-thing-video-box" });
 
         this._createStrip();
         this._createContentBox();
@@ -94,15 +91,14 @@ VideoThing.prototype = {
 
     _createContentBox : function() {
         this._contentBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         name: "video-thing-content-box" });
-
-        this._contentBox.set_style(this._style);
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               style: this._style,
+                               name: "video-thing-content-box" });
 
         this._videoBox.append(this._contentBox,
-                                Tb.BoxPackFlags.EXPAND);
+                              TheBoard.BoxPackFlags.EXPAND);
     },
 
     _createStrip : function() {
@@ -112,24 +108,23 @@ VideoThing.prototype = {
                                   filename: _STRIP_CELL_IMAGE });
 
         this._videoBox.append(strip,
-                              Tb.BoxPackFlags.NONE);
+                              TheBoard.BoxPackFlags.NONE);
     },
 
     _createPlaybackBox : function() {
         this._playbackBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         name: "video-thing-playback-box" });
-
-        this._playbackBox.set_style(this._style);
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               style: this._style,
+                               name: "video-thing-playback-box" });
 
         this._createVideo();
         this._createVideoControlsBox();
         this._createVideoBorderBox();
 
         this._contentBox.append(this._playbackBox,
-                                Tb.BoxPackFlags.EXPAND);
+                                TheBoard.BoxPackFlags.EXPAND);
     },
 
     _createVideo : function() {
@@ -141,68 +136,64 @@ VideoThing.prototype = {
                             Lang.bind(this, this._onVideoProgressChanged));
 
         this._playbackBox.append(this._video,
-                                 Tb.BoxPackFlags.EXPAND);
+                                 TheBoard.BoxPackFlags.EXPAND);
     },
 
     _createVideoControlsBox : function() {
         // This box is needed to add proper spacing between the
         // video controls and the edge of video playback frame
         let controlsBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.HORIZONTAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.CENTER,
-                         name: "video-thing-controls-box" });
-
-        controlsBox.set_style(this._style);
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.CENTER,
+                               style: this._style,
+                               name: "video-thing-controls-box" });
 
         this._videoControlsBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.HORIZONTAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.CENTER,
-                         opacity: 0,
-                         visible: false,
-                         name: "video-thing-video-controls-box" });
-
-        this._videoControlsBox.set_style(this._style);
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.CENTER,
+                               opacity: 0,
+                               visible: false,
+                               style: this._style,
+                               name: "video-thing-video-controls-box" });
 
         this._createPlayButton();
         this._createProgressBar();
         this._createTimeLabel();
 
         controlsBox.append(this._videoControlsBox,
-                           Tb.BoxPackFlags.EXPAND);
+                           TheBoard.BoxPackFlags.EXPAND);
 
         this._playbackBox.append(controlsBox,
-                                 Tb.BoxPackFlags.FIXED);
+                                 TheBoard.BoxPackFlags.FIXED);
 
         this._playbackBox.set_fixed_child_align(controlsBox,
-                                                Tb.BoxAlignment.FILL,
-                                                Tb.BoxAlignment.END);
+                                                TheBoard.BoxAlignment.FILL,
+                                                TheBoard.BoxAlignment.END);
     },
 
     _createPlayButton : function() {
         this._playButton =
             new Mx.Button({ isToggle: true,
+                            style: this._style,
                             name: "video-thing-play-button" });
 
-        this._playButton.set_style(this._style);
-
         this._playButton.connect("notify::toggled",
                                  Lang.bind(this,
                                            this._onPlayButtonToggled));
 
         this._videoControlsBox.append(this._playButton,
-                                      Tb.BoxPackFlags.NONE);
+                                      TheBoard.BoxPackFlags.NONE);
     },
 
     _createProgressBar : function() {
         this._progressBar =
             new Mx.ProgressBar({ reactive: true,
                                  height: 12,
+                                 style: this._style,
                                  name: "video-thing-progress-bar" });
 
-        this._progressBar.set_style(this._style);
-
         this._updateProgressBar();
 
         this._progressBar.connect("button-press-event",
@@ -210,11 +201,11 @@ VideoThing.prototype = {
                                             this._onProgressBarButtonPressEvent));
 
         this._videoControlsBox.append(this._progressBar,
-                                      Tb.BoxPackFlags.EXPAND);
+                                      TheBoard.BoxPackFlags.EXPAND);
 
         this._videoControlsBox.set_child_align(this._progressBar,
-                                               Tb.BoxAlignment.FILL,
-                                               Tb.BoxAlignment.CENTER);
+                                               TheBoard.BoxAlignment.FILL,
+                                               TheBoard.BoxAlignment.CENTER);
     },
 
     _createTimeLabel : function() {
@@ -222,44 +213,41 @@ VideoThing.prototype = {
             new Mx.Label({ yAlign: Mx.Align.MIDDLE,
                            text: "00:12:00",
                            anchorY: -2,
+                           style: this._style,
                            name: "video-thing-time-label" });
 
-        this._timeLabel.set_style(this._style);
-
         this._updateTimeLabel();
 
         this._videoControlsBox.append(this._timeLabel,
-                                      Tb.BoxPackFlags.END);
+                                      TheBoard.BoxPackFlags.END);
 
         this._videoControlsBox.set_child_align(this._timeLabel,
-                                               Tb.BoxAlignment.START,
-                                               Tb.BoxAlignment.CENTER);
+                                               TheBoard.BoxAlignment.START,
+                                               TheBoard.BoxAlignment.CENTER);
     },
 
     _createVideoBorderBox : function() {
         this._videoBorderBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.HORIZONTAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         name: "video-thing-video-border-box" });
-
-        this._videoBorderBox.set_style(this._style);
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               style: this._style,
+                               name: "video-thing-video-border-box" });
 
         this._playbackBox.append(this._videoBorderBox,
-                                 Tb.BoxPackFlags.FIXED);
+                                 TheBoard.BoxPackFlags.FIXED);
 
         this._playbackBox.set_fixed_child_align(this._videoBorderBox,
-                                                Tb.BoxAlignment.FILL,
-                                                Tb.BoxAlignment.FILL);
+                                                TheBoard.BoxAlignment.FILL,
+                                                TheBoard.BoxAlignment.FILL);
     },
 
     _createCaptionText : function() {
         this._captionLabel =
             new Mx.Label({ xAlign: Mx.Align.MIDDLE,
+                           style: this._style,
                            name: "video-thing-caption-label" });
 
-        this._captionLabel.set_style(this._style);
-
         this._captionLabel.clutterText.lineAlignment = Pango.Alignment.CENTER;
 
         this._captionLabel.connect("key-press-event",
@@ -270,7 +258,7 @@ VideoThing.prototype = {
                                                          this._onCaptionTextChanged));
 
         this._contentBox.append(this._captionLabel,
-                                Tb.BoxPackFlags.NONE);
+                                TheBoard.BoxPackFlags.NONE);
     },
 
     _connectVideoSignals : function(fromState) {
@@ -346,6 +334,8 @@ VideoThing.prototype = {
             }
         }
 
+        this._updateVideoControlsVisibility();
+
         if (!fromState) {
             this.emit('save');
         }
@@ -486,6 +476,17 @@ VideoThing.prototype = {
                                this._formatTimeComponent(seconds);
     },
 
+    _updateVideoControlsVisibility : function() {
+        let visible = this._videoFilename &&
+                      (this.hover || this.active);
+
+        if (visible) {
+            this._showVideoControlsBox();
+        } else {
+            this._hideVideoControlsBox();
+        }
+    },
+
     _onCaptionTextKeyPressEvent : function(o, event) {
         let key = event.get_key_symbol();
 
@@ -542,22 +543,22 @@ VideoThing.prototype = {
     },
 
     enter : function() {
-        if (this._videoFilename) {
-            this._showVideoControlsBox();
-        }
+        this._updateVideoControlsVisibility();
     },
 
     leave : function() {
-        this._hideVideoControlsBox();
+        this._updateVideoControlsVisibility();
     },
 
     activate : function() {
         this._captionLabel.clutterText.editable = true;
         this._captionLabel.clutterText.grab_key_focus();
+        this._updateVideoControlsVisibility();
     },
 
     deactivate : function() {
         this._captionLabel.clutterText.editable = false;
+        this._updateVideoControlsVisibility();
     },
 
     loadState : function(state) {
@@ -600,11 +601,6 @@ VideoThing.prototype = {
     },
 
     destroy : function() {
-        if (this._playButtonClickedId) {
-            this._playButton.disconnect(this._playButtonClickedId);
-            delete this._playButtonClickedId;
-        }
-
         this._disconnectVideoSignals();
 
         if (this._videoBox) {
@@ -644,8 +640,7 @@ function createToolbar(args) {
                               visible: false });
 
     let toolBox =
-        new ToolBox.ToolBox({ title: Gettext.gettext("Load from"),
-                              isThingToolBox: true });
+        new ToolBox.ToolBox({ title: Gettext.gettext("Load from") });
 
     toolBox.addButton({ label: Gettext.gettext("File"),
                         actionName: "chooseFile" });
